Queue

Struct Queue 

pub struct Queue { /* private fields */ }
The queue itself, which consists of the SQLite connection and tasks to monitor running jobs.

Implementations

Source

impl Queue

pub async fn add_job(&self, job: Job) -> Result<Uuid>

Submit a job to the queue

pub async fn add_jobs(&self, jobs: Vec<Job>) -> Result<Vec<Uuid>>

Submit multiple jobs to the queue

pub async fn update_job(&self, job: JobUpdate) -> Result<()>

Update some aspects of a job. Jobs can not be updated while running or after they have finished.

pub async fn cancel_job(&self, job_id: Uuid) -> Result<()>

Cancel a job. Jobs can not be cancelled while are running or after they have finished.

Source

impl Queue

pub async fn get_job_status(&self, external_id: Uuid) -> Result<JobStatus>

Return information about a job

pub async fn get_jobs_by_name( &self, name: String, limit: usize, ) -> Result<Vec<JobStatus>>

Get jobs by their name, ordered by the most recently added.

pub async fn num_active_jobs(&self) -> Result<NumActiveJobs>

Return counts about the number of jobs running and waiting to run.

Source

impl Queue

pub async fn new(file: &Path) -> Result<Queue>

Open or create a Queue database at the given path.

pub fn builder(path: &Path) -> QueueOptions<'_>

Create a builder object for a Queue

pub async fn with_options(options: QueueOptions<'_>) -> Result<Queue>

Open or create a Queue database with the given [LocalQueueOptions].

pub async fn close(&self, timeout: Duration) -> Result<()>

Stop the queue, and wait for existing workers to finish.

Source

impl Queue

pub async fn add_recurring_job( &self, id: String, schedule: RecurringJobSchedule, job: Job, run_immediately: bool, ) -> Result<(), Error>

Add a new recurring job to the queue, returning an error if a job with this external ID already exists.

pub async fn update_recurring_job( &self, id: String, schedule: RecurringJobSchedule, job: Job, ) -> Result<(), Error>

Update a recurring job. Returns an error if the job does not exist.

pub async fn upsert_recurring_job( &self, id: String, schedule: RecurringJobSchedule, job: Job, run_immediately_on_insert: bool, ) -> Result<(), Error>

Add a new recurring job, or update an existing one.

pub async fn delete_recurring_job(&self, id: String) -> Result<(), Error>

Remove a recurring job and unschedule any scheduled jobs for it.

pub async fn get_recurring_job_info( &self, id: String, ) -> Result<RecurringJobInfo, Error>

Return information about a recurring job and its latest execution

pub async fn list_recurring_jobs_with_prefix( &self, prefix: &str, ) -> Result<Vec<String>, Error>

Return the IDs of all recurring jobs with the given prefix